##  Enabling the Subscription Type Accountable
The subscription type ‘Accountable’ is not visible by default when creating a subscription role or when subscribing to fact sheets. If you need it, you must first activate it in the admin settings.
To enable the subscription type ‘Accountable’, follow these steps:
  1. In the administration area, select General.
  2. Check the Accountable checkbox under Subscription Type.
  3. Click Save to apply the change.
